ssm-ecs

## AWS Setup

#### Create SSM Document

#### Install SSM Agent

https://aws.amazon.com/premiumsupport/knowledge-center/install-ssm-agent-ec2-linux/

## Installation

#### Install pip

This varies per operating system but for Debian/Ubuntu it can be installed using:
```bash
sudo apt install python3-pip
```

#### Install ecs-ssm

```bash
pip3 install ecs-ssm
```

#### Install Session Manager Plugin

https://docs.aws.amazon.com/systems-manager/latest/userguide/session-manager-working-with-install-plugin.html

#### Configure AWS Credentials

```bash
aws configure
```

## Usage
